@@ -1,7 +1,7 @@
 package Perinci::Result::Format;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -148,7 +148,7 @@ our %Formats = (
 sub format {
     require Data::Format::Pretty;
 
-    my ($res, $format) = @_;
+    my ($res, $format, $is_naked) = @_;
 
     my $fmtinfo = $Formats{$format} or return undef;
     my $formatter = $fmtinfo->[0];
@@ -170,8 +170,9 @@ sub format {
     } else {
         my %o;
         $o{color} = 0 if !$deco && $format =~ /json|yaml|perl/;
+        my $data = $is_naked ? $res->[2] : $res;
         return Data::Format::Pretty::format_pretty(
-            $res, {%o, module=>$formatter});
+            $data, {%o, module=>$formatter});
     }
 }
 
@@ -190,7 +191,7 @@ Perinci::Result::Format - Format envelope result
 
 =head1 VERSION
 
-This document describes version 0.41 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-09-03.
+This document describes version 0.42 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
@@ -267,7 +268,7 @@ cannot handle circular references or complex types other than hash/array.
 
 None is currently exported/exportable.
 
-=head1 format($res, $format) => STR
+=head1 format($res, $format[ , $is_naked=0 ]) => STR
 
 Format enveloped result C<$res> with format named C<$format>.
 
